pub struct JsonStringScanner { /* private fields */ }Implementations
Sourceimpl JsonStringScanner
impl JsonStringScanner
pub fn new() -> Self
Sourcepub fn next(&mut self, input: &Simd8x64<u8>) -> JsonStringBlock
pub fn next(&mut self, input: &Simd8x64<u8>) -> JsonStringBlock
Return a mask of all string characters plus end quotes.
prev_escaped is overflow saying whether the next character is escaped. prev_in_string is overflow saying whether we’re still in a string.
Backslash sequences outside of quotes will be detected in stage 2.